/*
 * Copyright © 2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored By: Robert Carr <robert.carr@canonical.com>
 */

#ifndef MIR_TEST_FRAMEWORK_ANY_SURFACE_H_
#define MIR_TEST_FRAMEWORK_ANY_SURFACE_H_

#include "mir_toolkit/mir_client_library.h"
#include "mir/geometry/size.h"

namespace mir_test_framework
{
MirWindow* make_any_surface(MirConnection *connection);
MirWindow* make_surface(MirConnection *connection, mir::geometry::Size size, MirPixelFormat format);
}

#endif // MIR_TEST_FRAMEWORK_ANY_SURFACE_H_
